# object detection
from icevision.models.mmdet.models import faster_rcnn
from icevision.models.mmdet.models import yolox
from icevision.models.mmdet.models import retinanet
from icevision.models.mmdet.models import fcos
from icevision.models.mmdet.models import vfnet
from icevision.models.mmdet.models import cornernet
from icevision.models.mmdet.models import centripetalnet
from icevision.models.mmdet.models import sparse_rcnn
from icevision.models.mmdet.models import ssd

# segmentation
from icevision.models.mmdet.models import mask_rcnn
